@@ -3,7 +3,7 @@ BEGIN {
   $Perl::Achievements::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Perl::Achievements::VERSION = '0.2.1';
+  $Perl::Achievements::VERSION = '0.2.2';
 }
 # ABSTRACT: whoever die()s with the most badges win
 
@@ -50,11 +50,14 @@ with 'MooseX::Role::BuildInstanceOf' => {
 sub get_config_from_file {
     my ( $class, $file ) = @_;
 
+    return {} if not -f $file; 
+
     my $config = LoadFile( $file );
 
     # massage the config a wee bit
-    $_ = [ %$_ ] for 
-        $config->{user_args} = delete $config->{user};
+    if ( $config->{user} ) {
+        $_ = [ %$_ ] for $config->{user_args} = delete $config->{user};
+    }
 
     return $config;
 }
@@ -144,6 +147,16 @@ method initialize_environment {
     mkdir $dir;
     mkdir dir( $dir, 'achievements' );
     mkdir dir( $dir, 'scanned' );
+
+    my $config = file( $dir, 'config' )->openw;
+
+    print $config <<'END_CONFIG';
+# user: 
+#   name: Your Name Here
+#   url: http://yoursite.org/
+
+END_CONFIG
+
 }
 
 sub unlock_achievement {
@@ -202,7 +215,7 @@ Perl::Achievements - whoever die()s with the most badges win
 
 =head1 VERSION
 
-version 0.2.1
+version 0.2.2
 
 =head1 SYNOPSIS
 
